netapp_ontap.models.ad_domain API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.ad_domain`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AdDomainSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AdDomain object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `fqdn GET POST PATCH`

    The fully qualified domain name of the Windows Active Directory to which this CIFS server belongs. A CIFS server appears as a member of Windows server object in the Active Directory store. POST and PATCH only.

    Example: example.com

  `organizational_unit GET POST PATCH`

    Specifies the organizational unit within the Active Directory domain to associate with the CIFS server. POST and PATCH only.

  `password POST PATCH`

    The account password used to add this CIFS server to the Active Directory. This is not audited.

  `user GET POST`

    The user account used to add this CIFS server to the Active Directory. POST and DELETE only.